View source: R/run_MC_ISO_DELOC.R
| run_MC_ISO_DELOC | R Documentation |
Runs a Monte-Carlo (MC) simulation of isothermally stimulated luminescence (ISO-TL or ITL) using the one trap one recombination centre (OTOR) model. Delocalised refers to involvement of the conduction band.
run_MC_ISO_DELOC(
s,
E,
T = 20,
times,
clusters = 10,
N_e = 200,
n_filled = N_e,
R,
method = "par",
output = "signal",
...
)
s |
numeric (required): The frequency factor of the trap (s^-1) |
E |
numeric (required): Thermal activation energy of the trap (eV) |
T |
numeric (with default): Constant stimulation temperature (°C) |
times |
numeric (with default): The sequence of time steps within the simulation (s) |
clusters |
numeric (with default): The number of created clusters for the MC runs. The input can be the output of create_ClusterSystem. In that case |
N_e |
integer (with default): The total number of electron traps available (dimensionless). Can be a vector of |
n_filled |
integer (with default): The number of filled electron traps at the
beginning of the simulation (dimensionless). Can be a vector of |
R |
numeric (required): The delocalized retrapping ratio (dimensionless) |
method |
character (with default): Sequential |
output |
character (with default): Output is either the |
... |
further arguments, such as |
The model
I_{DELOC}(t) = -dn/dt = (s * exp(-E/(k_{B} * T_{ISO}))) * (n^2 / (N*R + n(1-R)))
Where in the function:
t := time
k_{B} := Boltzmann constant (8.617 x 10^-5 eV K^-1)
T_{ISO} = temperature of the isothermal experiment (°C)
n := n_filled, the number of filled electron traps at the beginning of the simulation
E := the trap depth (eV)
s := the frequency factor in (s^-1)
N := N_e, the total number of electron traps available (dimensionless)
R := the retrapping ratio for delocalized transitions
This function returns an object of class RLumCarlo_Model_Output which
is a list consisting of an array with dimension length(times) x clusters
and a numeric time vector.
0.1.0
Kreutzer, S., 2025. run_MC_ISO_DELOC(): Run Monte-Carlo Simulation for ISO-TL (delocalized transitions). Function version 0.1.0. In: Friedrich, J., Kreutzer, S., Pagonis, V., Schmidt, C., 2025. RLumCarlo: Monte-Carlo Methods for Simulating Luminescence Phenomena. R package version 0.1.10. https://r-lum.github.io/RLumCarlo/
Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
Pagonis, V., Friedrich, J., Discher, M., Müller-Kirschbaum, A., Schlosser, V., Kreutzer, S., Chen, R. and Schmidt, C., 2019. Excited state luminescence signals from a random distribution of defects: A new Monte Carlo simulation approach for feldspar. Journal of Luminescence 207, 266–272. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.jlumin.2018.11.024")}
Further reading
Chen, R., McKeever, S.W.S., 1997. Theory of Thermoluminescence and Related Phenomena. WORLD SCIENTIFIC. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1142/2781")}
run_MC_ISO_DELOC(
s = 3.5e12,
E = 1.45,
T = 200,
R = 1,
method = 'seq',
times = 0:100) %>%
plot_RLumCarlo(legend = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.