View source: R/run_MC_ISO_LOC.R
| run_MC_ISO_LOC | R Documentation |
Runs a Monte-Carlo (MC) simulation of isothermally stimulated luminescence (ISO-TL or ITL) using the generalized one trap (GOT) model. Localized transitions refer to transitions which do no involve the conduction or valence band. These transitions take place between the ground state and an excited state of the trapped charge, and also involve an energy state of the recombination centre.
run_MC_ISO_LOC(
s,
E,
T = 20,
times,
clusters = 10,
n_filled = 100,
r,
method = "par",
output = "signal",
...
)
s |
numeric (required): The frequency factor of the trap (s^-1) |
E |
numeric (required): Thermal activation energy of the trap (eV) |
T |
numeric (with default): Constant stimulation temperature (°C) |
times |
numeric (with default): The sequence of time steps within the simulation (s) |
clusters |
numeric (with default): The number of created clusters for the MC runs. The input can be the output of create_ClusterSystem. In that case |
n_filled |
integer (with default): The number of filled electron traps at the
beginning of the simulation (dimensionless). Can be a vector of |
r |
numeric (required): The retrapping ratio for localized transitions. |
method |
character (with default): Sequential |
output |
character (with default): output is either the |
... |
further arguments, such as |
The model
I_{LOC}(t) = -dn/dt = (s * exp(-E/(k_{B} * T_{ISO}))) * (n^2 / (r + n)))
Where in the function:
t := time (s)
k_{B} := Boltzmann constant (8.617 x 10^-5 eV K^-1)
T_{ISO} := isothermal temperature (°C)
n := n_filled
s := frequency factor of the trap (1/s)
E := activation energy of the trap (eV)
r := retrapping ratio for localized transitions
This function returns an object of class RLumCarlo_Model_Output which
is a list consisting of an array with dimension length(times) x clusters
and a numeric time vector.
0.1.0
Kreutzer, S., 2025. run_MC_ISO_LOC(): Run Monte-Carlo simulation for ISO-TL (localized transitions). Function version 0.1.0. In: Friedrich, J., Kreutzer, S., Pagonis, V., Schmidt, C., 2025. RLumCarlo: Monte-Carlo Methods for Simulating Luminescence Phenomena. R package version 0.1.10. https://r-lum.github.io/RLumCarlo/
Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
Pagonis, V., Friedrich, J., Discher, M., Müller-Kirschbaum, A., Schlosser, V., Kreutzer, S., Chen, R. and Schmidt, C., 2019. Excited state luminescence signals from a random distribution of defects: A new Monte Carlo simulation approach for feldspar. Journal of Luminescence 207, 266–272. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.jlumin.2018.11.024")}
run_MC_ISO_LOC(
E = 1.45,
s = 3.5e12,
T = 200,
times = 0:100,
method = 'seq',
r = 1) %>%
plot_RLumCarlo(legend = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.