Runs a Monte-Carlo (MC) simulation of linearly modulated optically stimulated luminescence (LM-OSL) using the one trap one recombination centre (OTOR) model. Delocalised refers to involvement of the conduction band.
run_MC_LM_OSL_DELOC(
A,
times,
clusters = 10,
N_e = 200,
n_filled = N_e,
R,
method = "par",
output = "signal",
...
)This function returns an object of class RLumCarlo_Model_Output which
is a list consisting of an array with dimension length(times) x clusters
and a numeric time vector.
numeric (required): The optical excitation rate from trap to conduction band (s^-1)
numeric (required): The sequence of time steps within the simulation (s)
numeric (with default): The number of created clusters for the MC runs. The input can be the output of create_ClusterSystem. In that case n_filled indicate absolute numbers of a system.
integer (with default): The total number of electron traps available (dimensionless). Can be a vector of length(clusters), shorter values are recycled.
integer (with default): The number of filled electron traps at the beginning
of the simulation (dimensionless). Can be a vector of length(clusters), shorter values are recycled.
numeric (required): The retrapping ratio for delocalized transitions
character (with default): Sequential 'seq' or parallel 'par'processing. In
the parallel mode the function tries to run the simulation on multiple CPU cores (if available) with
a positive effect on the computation time.
character (with default): output is either the 'signal' (the default)
or 'remaining_e' (the remaining charges/electrons in the trap)
further arguments, such as cores to control the number of used CPU cores or verbose to silence the terminal
0.1.0
Kreutzer, S., 2022. run_MC_LM_OSL_DELOC(): Run Monte-Carlo Simulation for LM-OSL (delocalized transitions). Function version 0.1.0. In: Friedrich, J., Kreutzer, S., Pagonis, V., Schmidt, C., 2022. RLumCarlo: Monte-Carlo Methods for Simulating Luminescence Phenomena. R package version 0.1.9. https://CRAN.R-project.org/package=RLumCarlo
Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
The model
$$ I_{DELOC}(t) = -dn/dt = A * t/P * (n^2 / (N*R + n(1-R))) $$
Where in the function:
t := time (s)
A := the optical excitation rate from trap to conduction band (1/s)
n := n_filled, the instantaneous number of electrons
R := the retrapping ratio for delocalized transitions
N := N_e, the total number of electron traps available (dimensionless)
P := total stimulation time (s)
Pagonis, V., Friedrich, J., Discher, M., Müller-Kirschbaum, A., Schlosser, V., Kreutzer, S., Chen, R. and Schmidt, C., 2019. Excited state luminescence signals from a random distribution of defects: A new Monte Carlo simulation approach for feldspar. Journal of Luminescence 207, 266–272. tools:::Rd_expr_doi("10.1016/j.jlumin.2018.11.024")
Further reading
Chen, R., McKeever, S.W.S., 1997. Theory of Thermoluminescence and Related Phenomena. WORLD SCIENTIFIC. tools:::Rd_expr_doi("10.1142/2781")
run_MC_LM_OSL_DELOC(
A = 0.12,
R = 0.1,
times = 0:50,
method = "seq",
clusters = 10) %>%
plot_RLumCarlo(legend = TRUE)
Run the code above in your browser using DataLab