Runs a Monte-Carlo (MC) simulation of continuous wave infrared stimulated luminescence (CW-IRSL) using the model for tunnelling transitions. Tunnelling refers to quantum mechanical tunnelling processes from the excited state of the trap, into a recombination centre.
run_MC_CW_IRSL_TUN(
A,
rho,
times,
clusters = 10,
r_c = 0,
delta.r = 0.1,
N_e = 200,
method = "seq",
output = "signal",
...
)This function returns an object of class RLumCarlo_Model_Output which
is a list consisting of an array with dimension length(times) x length(r) x clusters
and a numeric time vector.
numeric (required): The effective optical excitation rate for the tunnelling process
(s^-1).
numeric (required): The density of recombination centres (defined as \(\rho\)' in Huntley 2006) (dimensionless).
numeric (required): The sequence of time steps within the simulation (s).
numeric (with default): The number of created clusters for the MC runs. The input can be the output of create_ClusterSystem. In that case n_filled indicate absolute numbers of a system.
numeric (with default): Critical distance (>0) that must be provided if the
sample has been thermally and/or optically pretreated. This parameter expresses the fact
that electron-hole pairs within a critical radius r_c have already recombined.
numeric (with default): Increments of the dimensionless distance parameter r'
numeric (width default): The total number of electron traps available (dimensionless).
Can be a vector of length(clusters), shorter values are recycled.
character (with default): Sequential 'seq' or parallel 'par'processing. In
the parallel mode the function tries to run the simulation on multiple CPU cores (if available) with
a positive effect on the computation time.
character (with default): output is either the 'signal' (the default) or
'remaining_e' (the remaining charges/electrons in the trap)
further arguments, such as cores to control the number of used CPU cores or verbose to silence the terminal
0.2.0
Friedrich, J., Kreutzer, S., 2022. run_MC_CW_IRSL_TUN(): Run Monte-Carlo Simulation for CW-IRSL (tunnelling transitions). Function version 0.2.0. In: Friedrich, J., Kreutzer, S., Pagonis, V., Schmidt, C., 2022. RLumCarlo: Monte-Carlo Methods for Simulating Luminescence Phenomena. R package version 0.1.9. https://CRAN.R-project.org/package=RLumCarlo
Johannes Friedrich, University of Bayreuth (Germany), Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
The model
$$ I_{TUN}(r',t) = -dn/dt = A * exp(-(\rho')^{-1/3} * r')* n (r',t) $$
Where in the function:
A := effective optical excitation rate for the tunnelling process (s^-1)
r' := the dimensionless tunnelling radius
\(\rho\)' := rho' the dimensionless density of recombination centres (see Huntley (2006))
t := time (s)
n := the instantaneous number of electrons corresponding to the radius r' at time t
Huntley, D.J., 2006. An explanation of the power-law decay of luminescence. Journal of Physics: Condensed Matter, 18(4), 1359.
Pagonis, V., Friedrich, J., Discher, M., Müller-Kirschbaum, A., Schlosser, V., Kreutzer, S., Chen, R. and Schmidt, C., 2019. Excited state luminescence signals from a random distribution of defects: A new Monte Carlo simulation approach for feldspar. Journal of Luminescence 207, 266–272. tools:::Rd_expr_doi("10.1016/j.jlumin.2018.11.024")
Further reading
Aitken, M.J., 1985. Thermoluminescence dating. Academic Press.
Jain, M., Guralnik, B., Andersen, M.T., 2012. Stimulated luminescence emission from localized recombination in randomly distributed defects. Journal of Physics: Condensed Matter 24, 385402.
Chen, R., McKeever, S.W.S., 1997. Theory of Thermoluminescence and Related Phenomena. WORLD SCIENTIFIC. tools:::Rd_expr_doi("10.1142/2781")
run_MC_CW_IRSL_TUN(
A = 0.8,
rho = 1e-4,
times = 0:50,
r_c = 0.05,
delta.r = 0.1,
method = "seq",
clusters = 10,
output = "signal") %>%
plot_RLumCarlo(norm = TRUE, legend = TRUE)
Run the code above in your browser using DataLab