Runs a Monte-Carlo (MC) simulation of isothermally stimulated luminescence (ISO-TL or ITL) using the one trap one recombination centre (OTOR) model. Delocalised refers to involvement of the conduction band.
run_MC_ISO_DELOC(
s,
E,
T = 20,
times,
clusters = 10,
N_e = 200,
n_filled = N_e,
R,
method = "par",
output = "signal",
...
)This function returns an object of class RLumCarlo_Model_Output which
is a list consisting of an array with dimension length(times) x clusters
and a numeric time vector.
numeric (required): The frequency factor of the trap (s^-1)
numeric (required): Thermal activation energy of the trap (eV)
numeric (with default): Constant stimulation temperature (°C)
numeric (with default): The sequence of time steps within the simulation (s)
numeric (with default): The number of created clusters for the MC runs. The input can be the output of create_ClusterSystem. In that case n_filled indicate absolute numbers of a system.
integer (with default): The total number of electron traps available (dimensionless). Can be a vector of length(clusters), shorter values are recycled.
integer (with default): The number of filled electron traps at the
beginning of the simulation (dimensionless). Can be a vector of length(clusters), shorter values are recycled.
numeric (required): The delocalized retrapping ratio (dimensionless)
character (with default): Sequential 'seq' or parallel 'par'processing. In
the parallel mode the function tries to run the simulation on multiple CPU cores (if available) with
a positive effect on the computation time.
character (with default): Output is either the 'signal' (the default) or
'remaining_e' (the remaining charges, electrons, in the trap)
further arguments, such as cores to control the number of used CPU cores or verbose to silence the terminal
0.1.0
Kreutzer, S., 2022. run_MC_ISO_DELOC(): Run Monte-Carlo Simulation for ISO-TL (delocalized transitions). Function version 0.1.0. In: Friedrich, J., Kreutzer, S., Pagonis, V., Schmidt, C., 2022. RLumCarlo: Monte-Carlo Methods for Simulating Luminescence Phenomena. R package version 0.1.9. https://CRAN.R-project.org/package=RLumCarlo
Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
The model
$$ I_{DELOC}(t) = -dn/dt = (s * exp(-E/(k_{B} * T_{ISO}))) * (n^2 / (N*R + n(1-R))) $$
Where in the function:
t := time
\(k_{B}\) := Boltzmann constant (8.617 x 10^-5 eV K^-1)
\(T_{ISO}\) = temperature of the isothermal experiment (°C)
n := n_filled, the number of filled electron traps at the beginning of the simulation
E := the trap depth (eV)
s := the frequency factor in (s^-1)
N := N_e, the total number of electron traps available (dimensionless)
R := the retrapping ratio for delocalized transitions
Pagonis, V., Friedrich, J., Discher, M., Müller-Kirschbaum, A., Schlosser, V., Kreutzer, S., Chen, R. and Schmidt, C., 2019. Excited state luminescence signals from a random distribution of defects: A new Monte Carlo simulation approach for feldspar. Journal of Luminescence 207, 266–272. tools:::Rd_expr_doi("10.1016/j.jlumin.2018.11.024")
Further reading
Chen, R., McKeever, S.W.S., 1997. Theory of Thermoluminescence and Related Phenomena. WORLD SCIENTIFIC. tools:::Rd_expr_doi("10.1142/2781")
run_MC_ISO_DELOC(
s = 3.5e12,
E = 1.45,
T = 200,
R = 1,
method = 'seq',
times = 0:100) %>%
plot_RLumCarlo(legend = TRUE)
Run the code above in your browser using DataLab